@@ -11,7 +11,7 @@ from functools import lru_cache
 from polyglot.builtins import environ_item, hasenv
 
 __appname__   = 'calibre'
-numeric_version = (7, 16, 0)
+numeric_version = (7, 18, 0)
 __version__   = '.'.join(map(str, numeric_version))
 git_version   = None
 __author__    = "Kovid Goyal <kovid@kovidgoyal.net>"
@@ -260,6 +260,7 @@ class ExtensionsImporter:
             'speedup',
             'html_as_json',
             'fast_css_transform',
+            'fast_html_entities',
             'unicode_names',
             'html_syntax_highlighter',
             'hyphen',
@@ -275,7 +276,7 @@ class ExtensionsImporter:
             'uchardet',
         )
         if iswindows:
-            extra = ('winutil', 'wpd', 'winfonts', 'winsapi', 'winspeech')
+            extra = ('winutil', 'wpd', 'winfonts',)
         elif ismacos:
             extra = ('usbobserver', 'cocoa', 'libusb', 'libmtp')
         elif isfreebsd or ishaiku or islinux:
@@ -488,7 +489,36 @@ def get_umask():
     return mask
 
 
-# call this at startup as it changed process global state, which doesn't work
+# call this at startup as it changes process global state, which doesn't work
 # with multi-threading. It's absurd there is no way to safely read the current
 # umask of a process.
 get_umask()
+
+
+@lru_cache(maxsize=2)
+def bundled_binaries_dir() -> str:
+    if ismacos and hasattr(sys, 'frameworks_dir'):
+        base = os.path.join(os.path.dirname(sys.frameworks_dir), 'utils.app', 'Contents', 'MacOS')
+        return base
+    if iswindows and hasattr(sys, 'frozen'):
+        base = sys.extensions_location if hasattr(sys, 'new_app_layout') else os.path.dirname(sys.executable)
+        return base
+    if (islinux or isbsd) and getattr(sys, 'frozen', False):
+        return os.path.join(sys.executables_location, 'bin')
+    return ''
+
+
+@lru_cache(2)
+def piper_cmdline() -> tuple[str, ...]:
+    ext = '.exe' if iswindows else ''
+    if bbd := bundled_binaries_dir():
+        if ismacos:
+            return (os.path.join(sys.frameworks_dir, 'piper', 'piper'),)
+        return (os.path.join(bbd, 'piper', 'piper' + ext),)
+    if pd := os.environ.get('PIPER_TTS_DIR'):
+        return (os.path.join(pd, 'piper' + ext),)
+    import shutil
+    exe = shutil.which('piper-tts')
+    if exe:
+        return (exe,)
+    return ()
