@@ -9,14 +9,12 @@ import json
 import os
 import time
 from functools import partial
+
 from qt.core import QAction, QDialog, QIcon, pyqtSignal
 
 from calibre.constants import ismacos, iswindows
 from calibre.db.constants import DATA_DIR_NAME
-from calibre.gui2 import (
-    Dispatcher, config, elided_text, error_dialog, info_dialog, open_local_file,
-    question_dialog,
-)
+from calibre.gui2 import Dispatcher, config, elided_text, error_dialog, info_dialog, open_local_file, question_dialog
 from calibre.gui2.actions import InterfaceAction
 from calibre.gui2.dialogs.choose_format import ChooseFormatDialog
 from calibre.ptempfile import PersistentTemporaryFile
