@@ -15,7 +15,6 @@ from io import BytesIO
 from textwrap import wrap
 from threading import Event, Thread
 
-from PIL import Image
 from qt.core import (
     QAbstractItemView,
     QApplication,
@@ -878,9 +877,10 @@ class GridView(QListView):
         r, g, b = gprefs['cover_grid_color']
         tex = gprefs['cover_grid_texture']
         pal = self.palette()
-        pal.setColor(QPalette.ColorRole.Base, QColor(r, g, b))
+        bgcol = QColor(r, g, b)
+        pal.setColor(QPalette.ColorRole.Base, bgcol)
         self.setPalette(pal)
-        ss = ''
+        ss = f'background-color: {bgcol.name()}; '
         if tex:
             from calibre.gui2.preferences.texture_chooser import texture_path
             path = texture_path(tex)
@@ -1016,6 +1016,7 @@ class GridView(QListView):
                                                                      as_what='pil_image')
             if has_cover:
                 if tcdata is None:
+                    from PIL import Image
                     # The cached cover is up-to-date. Convert the cached bytes
                     # to a PIL image
                     cache_valid = True
